Orange for spectral data
========================

This is an add-on for [Orange3](http://orange.biolab.si) for the analysis
of spectral data.

Installation
------------

To install the add-on, run

    python setup.py install

To register this add-on with Orange, but keep the code in the development
directory (do not copy it to Python's site-packages directory), run

    python setup.py develop

Usage
-----

After the installation, the widgets from this add-on are registered with
Orange. To run Orange from the terminal, use

    python -m Orange.canvas

The new widget appears in the toolbox bar under the section Infrared.
